#include <Wire.h>
#include <Adafruit_Sensor.h>
#include "Adafruit_BMP3XX.h"

#define AVG_PRESSURE_MBAR (1030)

Adafruit_BMP3XX bmp;

float Temp;
float Pressure;

int TempFactor;
int PressureFactor;

int PowerState = 0;

bool Override;
bool OverrideSetting;
void setup() {
  pinMode(10, OUTPUT);//Activity Indicator
  pinMode(11, OUTPUT);//Power State Indicator
  pinMode(12, INPUT);//Overide Indicator

  pinMode(9, OUTPUT);

  
  Serial.begin(115200);

  if (!bmp.begin_I2C()) {   // hardware I2C mode, can pass in address & alt Wire
    Serial.println("Could not find a valid BMP3 sensor, check wiring!");
    while (1);
  }

  // Set up oversampling and filter initialization
  bmp.setTemperatureOversampling(BMP3_OVERSAMPLING_8X);
  bmp.setPressureOversampling(BMP3_OVERSAMPLING_4X);
  bmp.setIIRFilterCoeff(BMP3_IIR_FILTER_COEFF_3);
  bmp.setOutputDataRate(BMP3_ODR_50_HZ);
}

void loop() {
  if (! bmp.performReading()) {
    Serial.println("Failed to perform reading :(");
    return;
  }
  
  Override = digitalRead(12);

  //Temperature and Pressure Reading
  Temp = bmp.temperature; //Temperature in Celcius
  Pressure = bmp.pressure/100; //Pressure in millibar

  //Temperature Fator Calculation
  if(Temp > 1){
    TempFactor = 0;
  }
  else if(Temp<1){
    TempFactor = 1;
  }
  else if(Temp<-5){
    TempFactor = 2;
  }
  else if(Temp<-10){
    TempFactor = 3;
  }
  else if(Temp<-20){
    TempFactor = 4;
  }

  //Pressure Factor Calculation
  if(Pressure<AVG_PRESSURE_MBAR-10){
    PressureFactor = 1;
  }
  else if(Pressure<AVG_PRESSURE_MBAR-20){
    PressureFactor = 2;
  }
  else{
    PressureFactor = 0;
  }

  //Output Contorl
  if(Override == HIGH){
    pinMode(10, INPUT);
    OverrideSetting = digitalRead(10);
    if(OverrideSetting == HIGH){
      PowerState = 6;
    }
    else{
      PowerState = 0;
    }
  }
  else{
    PowerState = TempFactor + PressureFactor;
  }

  analogWrite(9,(42.5 * PowerState));
 
  digitalWrite(11,HIGH);
  delay(1000/PowerState);
  
  digitalWrite(11,LOW);
  delay(1000/PowerState);
}
